# Pipeless Plugins

> IMPORTANT: THIS MODULE IS DEPRECATED IN FAVOR OF THE NEW PLUGIN SYSTEM
> Check the [plugins docs](https://www.pipeless.ai/docs/v0/plugins) for more information about the new plugin system.

[Pipeless](https://pipeless.ai) is an open source multimedia framework with focus on computer vision.

This package contains a list of usefull plugins to use when building applications with Pipeless.

## Plugin List

- [Kafka](src/pipeless_ai_plugins/kafka/): easily export data to Kafka topics